@@ -1,25 +1,27 @@
+/* $Xorg: FSConnServ.c,v 1.4 2001/02/09 02:03:25 xorgcvs Exp $ */
+
 /*
  * Copyright 1990 Network Computing Devices;
  * Portions Copyright 1987 by Digital Equipment Corporation
  *
- * Permission to use, copy, modify, distribute, and sell this software
- * and its documentation for any purpose is hereby granted without fee,
- * provided that the above copyright notice appear in all copies and
- * that both that copyright notice and this permission notice appear
- * in supporting documentation, and that the names of Network Computing
- * Devices or Digital not be used in advertising or publicity pertaining
- * to distribution of the software without specific, written prior
- * permission. Network Computing Devices or Digital make no representations
- * about the suitability of this software for any purpose.  It is provided
+ * Permission to use, copy, modify, distribute, and sell this software 
+ * and its documentation for any purpose is hereby granted without fee, 
+ * provided that the above copyright notice appear in all copies and 
+ * that both that copyright notice and this permission notice appear 
+ * in supporting documentation, and that the names of Network Computing 
+ * Devices or Digital not be used in advertising or publicity pertaining 
+ * to distribution of the software without specific, written prior 
+ * permission. Network Computing Devices or Digital make no representations 
+ * about the suitability of this software for any purpose.  It is provided 
  * "as is" without express or implied warranty.
  *
  * NETWORK COMPUTING DEVICES AND  DIGITAL DISCLAIM ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
+ * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF 
  * MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL NETWORK COMPUTING DEVICES
- * OR DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES
- * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
- * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
- * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
+ * OR DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES 
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, 
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, 
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS 
  * SOFTWARE.
  */
 
@@ -48,6 +50,7 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
+/* $XFree86: xc/lib/FS/FSConnServ.c,v 3.10 2001/10/28 03:32:27 tsi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -76,7 +79,8 @@ in this Software without prior written authorization from The Open Group.
 #define FS_CONNECTION_RETRIES 5
 
 XtransConnInfo
-_FSConnectServer(char *server_name)
+_FSConnectServer(server_name)
+    char       *server_name;
 {
     XtransConnInfo trans_conn = NULL;	/* transport connection object */
     int retry, connect_stat;
@@ -131,7 +135,8 @@ _FSConnectServer(char *server_name)
  */
 
 void
-_FSDisconnectServer(XtransConnInfo trans_conn)
+_FSDisconnectServer(trans_conn)
+    XtransConnInfo	trans_conn;
 
 {
     (void) _FSTransClose(trans_conn);
@@ -144,7 +149,8 @@ _FSDisconnectServer(XtransConnInfo trans_conn)
  * 2) if the connection can be read, must enqueue events and handle errors,
  * until the connection is writable.
  */
-void _FSWaitForWritable(FSServer *svr)
+void _FSWaitForWritable(svr)
+    FSServer     *svr;
 {
     fd_set	r_mask;
     fd_set	w_mask;
@@ -206,7 +212,8 @@ void _FSWaitForWritable(FSServer *svr)
 }
 
 
-void _FSWaitForReadable(FSServer *svr)
+void _FSWaitForReadable(svr)
+    FSServer     *svr;
 {
     fd_set	r_mask;
     int         result;
@@ -220,9 +227,9 @@ void _FSWaitForReadable(FSServer *svr)
     } while (result <= 0);
 }
 
-void _FSSendClientPrefix(
-    FSServer		*svr,
-    fsConnClientPrefix	*client)
+void _FSSendClientPrefix(svr, client)
+    FSServer     *svr;
+    fsConnClientPrefix *client;
 {
     struct iovec iovarray[5],
                *iov = iovarray;
